function Create(self)
	--Make this unselectable.
	self.Team = -1;

	--The acceleration value in pixels per frame.
	self.acceleration = 0.15;

	--How much to slow down when not being moved in pixels per frame.
	self.deceleration = 0.3;

	--How hard to break.  The larger, the harder to break.
	self.brakefactor = 3;

	--Maximum speed that can be accelerated to.
	self.maxspeed = 15;

	--Distance to hover from ground when in normal mode.
	self.hoverheighta = 35;

	--Distance to hover from ground when in alternate mode.
	self.hoverheightb = 15;

	--How softly the hoverboard should move to its desired position (the higher this number is, the easier it is to fall of from crashing into the ground below).
	self.landsoftness = 10;

	--Multiplied by the Y velocity to stop from hitting the ground.
	self.landdamping = 0.7;

	--The higher the number, the slower the board corrects itself, 1 being not at all and 0 being always upright.
	self.rotsoftness = 0.95;

	--Jump velocity.
	self.jumpvel = 15;

	--If the board is active.
	self.active = false;

	--The range an actor must be within to enter the vehicle.
	self.range = 50;

	--The maximum allowed drastic change in X velocity before the actor inside is knocked out of the vehicle.
	self.maxhalt = 10;

	--Stores the velocity from last frame.
	self.lastVel = Vector(0,0);

	--Minimum time between jumps, in milliseconds.
	self.jumptime = 100;

	--Minimum time between entering and exiting the vehicle.
	self.inouttime = 1000;

	--The actor inside of the vehicle.
	self.controlactor = nil;

	--The actor's legs.
	self.leg = {};

	--Whether it should be HFlipped or not.
	self.shouldflip = false;

	--Timer to time between jumps.
	self.jumptimer = Timer();

	--Timer between exiting/entering the vehicle.
	self.inouttimer = Timer();

	--How long the alternate jump has been charged for.
	self.chargetimer = Timer();

	--Whether the vehicle is in alternate mode or not.
	self.altmode = false;

	--How far above the board the actor should be.
	self.abovedist = 0;

	--The hoverboard's two hover panels (glow effects).
	self.pad1 = CreateAEmitter("Hoverboard Hover Panel");
	MovableMan:AddParticle(self.pad1);
	self.pad2 = CreateAEmitter("Hoverboard Hover Panel");
	MovableMan:AddParticle(self.pad2);

	--Spawn a marker that says this vehicle's name.
	self.marker = CreateHeldDevice(string.gsub(self.PresetName," Spawned","") .. " Marker");
	MovableMan:AddItem(self.marker);
end

function Update(self)
	if self.active == true then
		if MovableMan:IsActor(self.controlactor) then
			--Set the actor's movement and position variables relative to this.
			self.controlactor.Pos = self.Pos - Vector(lengthdir_x(self.abovedist,-math.deg(self.RotAngle) + 90),lengthdir_y(self.abovedist,-math.deg(self.RotAngle) + 90));
			self.controlactor.Vel = self.Vel;
			self.controlactor.RotAngle = self.RotAngle;
			self.controlactor.AngularVel = self.AngularVel;

			--If needed, flip the board.
			if self.shouldflip == true then
				self.HFlipped = true;
				self.controlactor.HFlipped = true;
			else
				self.HFlipped = false;
				self.controlactor.HFlipped = false;
			end

			--Hover.
			local hoverpoint = 0;
			--When in normal mode, set the desired position to the normal height.
			if self.altmode == false then
				hoverpoint = SceneMan:MovePointToGround(self.Pos + Vector(self.Vel.X,0),0,3).Y - self.hoverheighta;
			else
			--When in alternate mode, set it to the other height.
				hoverpoint = SceneMan:MovePointToGround(self.Pos + Vector(self.Vel.X,0),0,3).Y - self.hoverheightb;
			end

			--If the board is below the desired position...
			if self.Pos.Y > hoverpoint then
				--Hover at the right position.
				--This gives it the right position.
				self.Pos.Y = ((self.Pos.Y * self.landsoftness) + hoverpoint) / (self.landsoftness + 1);
				--This minimizes the effects of gravity.
				if self.Vel.Y > 0 then
					self.Vel.Y = self.Vel.Y * self.landdamping;
				end
			end

			--Get the controller.
			local controller = self:GetController();

			--Keeps track of whether it's moving or not for future use.
			local ismoving = false;

			--If the hoverboard is close enough to its desired position...
			if self.Pos.Y > hoverpoint - 25 then
				--If the player is telling it to jump...
				if controller:IsState(Controller.BODY_JUMP) and self.jumptimer:IsPastSimMS(self.jumptime) then
					if self.altmode == false then
						--If it's in normal mode, jump.
						self.Vel.Y = -self.jumpvel;
						--Also reset the timer between jumps.
						self.jumptimer:Reset();
					else
						--If it's in alternate mode, calculate how high to jump depending on how long the button has been held down.
						local jumpmod = 1 - (self.chargetimer:LeftTillSimMS(0) / 1400) * 0.4;
						--Limit it to a maximum of 1.4 times the jump height.
						if jumpmod > 1.4 then
							jumpmod = 1.4;
						end
						--Jump.
						self.Vel.Y = -self.jumpvel * jumpmod;
						--Reset the timer between jumps.
						self.jumptimer:Reset();
						--Also reset the timer for charging jumps.
						self.chargetimer:Reset();
					end
				end
			else
				--If the board is in the air, reset both timers.
				self.chargetimer:Reset();
				self.jumptimer:Reset();
			end

			--Stay upright.
			self.RotAngle = self.RotAngle * self.rotsoftness;
			self.AngularVel = self.AngularVel * self.rotsoftness;

			--Calculate the angle of the slope the hoverboard is on.
			--The left side of the hoverboard.
			local pos1 = SceneMan:MovePointToGround(self.Pos - Vector(14,10),0,3);
			--The right side of the hoverboard.
			local pos2 = SceneMan:MovePointToGround(self.Pos + Vector(14,-10),0,3);
			--The angle of the slope.
			local desiredangle = vector_point_direction(pos2,pos1);

			--If the player is pushing left...
			if controller:IsState(Controller.MOVE_LEFT) then
				if self.Vel.X <= 0 then
					--If we're just going forward normally...
					if self.Vel.X > -self.maxspeed then
						--If we're not going beyond the maximum speed, accelerate leftward.
						self.Vel = self.Vel - Vector(lengthdir_x(self.acceleration,desiredangle),lengthdir_y(self.acceleration,desiredangle));
					end
				elseif self.Vel.X > 0 then
					--If we're going in the opposite direction of the current velocity, also factor in braking.
					self.Vel = self.Vel - Vector(lengthdir_x(self.acceleration * self.brakefactor,desiredangle),lengthdir_y(self.acceleration,desiredangle));
					--The braking is faster than the acceleration, so if we start going beyond 0, it means we've braked too much.  Cap it off.
					if self.Vel.X < 0 then
						self.Vel.X = 0;
					end
				end

				--Make sure the actor and board know that they should face the way we're moving.
				if self.Vel.X < 0 then
					self.shouldflip = true;
				end

				--Tell the board we're moving it.
				ismoving = true;
			end

			--This is all the same as moving left, but reversed so we go right.
			if controller:IsState(Controller.MOVE_RIGHT) then
				if self.Vel.X >= 0 then
					if self.Vel.X < self.maxspeed then
						self.Vel = self.Vel + Vector(lengthdir_x(self.acceleration,desiredangle),lengthdir_y(self.acceleration,desiredangle));
					end
				elseif self.Vel.X < 0 then
					self.Vel = self.Vel + Vector(lengthdir_x(self.acceleration * self.brakefactor,desiredangle),lengthdir_y(self.acceleration,desiredangle));
					if self.Vel.X > 0 then
						self.Vel.X = 0;
					end
				end
				if self.Vel.X > 0 then
					self.shouldflip = false;
				end
				ismoving = true;
			end

			--If the board is not being moved...
			if ismoving == false then
				if self.Vel.X < 0 then
					--If we're going left (negative numbers), add the deceleration so we slow down.
					self.Vel.X = self.Vel.X + self.deceleration;
					--Again, we cap off the speed in case it went too far.
					if self.Vel.X > 0 then
						self.Vel.X = 0;
					end
				else
					--If we're going right (positive numbers), subtract the deceleration so we slow down.
					self.Vel.X = self.Vel.X - self.deceleration;
					if self.Vel.X < 0 then
						self.Vel.X = 0;
					end
				end
			end

			--If the player is hitting crouch...
			if controller:IsState(Controller.BODY_CROUCH) then
				--Go into alternate mode.
				self.altmode = true;
			else
				--If the player isn't hitting crouch, we go out of alternate mode.
				self.altmode = false;
				--We also reset the jump charge.
				self.chargetimer:Reset();
			end

			--Fire the actor's weapon.
			if controller:IsState(Controller.WEAPON_FIRE) then
				self.controlactor:GetController():SetState(Controller.WEAPON_FIRE,true);
			end

			--Reload the actor's weapon.
			if controller:IsState(Controller.AIM_SHARP) then
				self.controlactor:GetController():SetState(Controller.WEAPON_RELOAD,true);
			end

			--Aim up.
			if controller:IsState(Controller.AIM_UP) then
				self.controlactor:GetController():SetState(Controller.AIM_UP,true);
			end

			--Aim down.
			if controller:IsState(Controller.AIM_DOWN) then
				self.controlactor:GetController():SetState(Controller.AIM_DOWN,true);
			end

			--Count how many legs the actor has.
			local count = 0;
			for i = 1,#self.leg do
				if self.leg[i].RootID == self.controlactor.ID then
					count = count + 1;
				end
			end

			--Calculate the difference between last frame's speed and the current speed, to detect large changes.
			local haltspeed = self.Vel.X - self.lastVel.X;

			--If there is a sudden stop, such as hitting a wall, knock off the actor.
			if haltspeed > self.maxhalt or haltspeed < -self.maxhalt then
				DeactivateVehicle(self,true);
			end

			--Update the last speed.
			if self.active == true then
				self.lastVel = Vector(self.Vel.X,self.Vel.Y);
			end

			--Disembark if up and down are pushed.
			if controller:IsState(Controller.PIE_MENU_ACTIVE) then
				--Turn the pie menu off again.
				self:GetController():SetState(Controller.PIE_MENU_ACTIVE,false);
				if self.inouttimer:IsPastSimMS(self.inouttime) then
					--Only actually get out if 
					DeactivateVehicle(self,true);
				end
			end

			--Fall down if rotated too far.
			if self.RotAngle > math.pi/2 or self.RotAngle < -math.pi/2 then
				DeactivateVehicle(self,true);
			end

			--If the player switched away from the board, deactivate it.
			if self:IsPlayerControlled() == false then
				DeactivateVehicle(self,false);
			end

			--If there are no legs, kick the actor off!
			if count == 0 then
				DeactivateVehicle(self,true);
			end
		else
			--If the driver isn't existent, deactivate.
			DeactivateVehicle(self,false);
		end
	else
	--This all runs when the vehicle is off, and only then.
		--Turn off the effects.
		self.pad1:EnableEmission(false);
		self.pad2:EnableEmission(false);
		--Update the marker's position.
		self.marker.Pos = self.Pos;
		--Check for actors that are trying to enter the vehicle.
		--Calculate the distance between the actor and this.
		local diff = 0;
		for actor in MovableMan.Actors do
			diff = math.sqrt((self.Pos.X - actor.Pos.X) ^ 2 + (self.Pos.Y - actor.Pos.Y) ^ 2);
			--If the actor is in range, AND the button is pushed, AND the actor is not another vehicle, AND it has been long enough before getting in and out...
			if diff <= self.range and diff >= -self.range and actor:GetController():IsState(Controller.PIE_MENU_ACTIVE) and actor:IsInGroup("Vehicles") == false and self.inouttimer:IsPastSimMS(self.inouttime) then
				--Turn on the board.
				self.active = true;
				--Remember the actor.
				self.controlactor = actor;
				--Switch to the board.
				ActivityMan:GetActivity():SwitchToActor(self,self.controlactor:GetController().Player,self.controlactor.Team);
				--Flip the right way.
				self.shouldflip = self.controlactor.HFlipped;
				--Turn off the pie menu again.
				self.controlactor:GetController():SetState(Controller.PIE_MENU_ACTIVE,false);
				--Disable the actor's AI.
				self.controlactor:SetControllerMode(Controller.CIM_DISABLED,-1);
				--Tell the actor to look directly forward,
				self.controlactor:SetAimAngle(0);
				--Stop rotating (this allows for you to grab a spinning board mid-air and get on it again).
				self.AngularVel = 0;
				--Reset the timer between getting in and out.
				self.inouttimer:Reset();
				--Allow the board to be hit again.
				self.GetsHitByMOs = true;
				--Face straight.
				self.RotAngle = 0;
				--Turn on the effects.
				self.pad1:EnableEmission(true);
				self.pad1:TriggerBurst();
				self.pad2:EnableEmission(true);
				self.pad2:TriggerBurst();
				self.marker.ToDelete = true;
				--Update the last velocity to the current one.
				self.lastVel = self.Vel;
				--Store the actor's legs as pointers so that if he has none, he falls off the board.
				local mo = nil;
				local count = 1;
				for i = 1,MovableMan:GetMOIDCount() - 1 do
					mo = MovableMan:GetMOFromID(i);
					if mo.RootID == self.controlactor.ID and mo:IsGeneric() == true then
						if ToAttachable(mo).ClassName == "Leg" then
							--Get how high above the board the actor should be, using the length of its first leg and the joint offset of its first leg.
							if self.abovedist == 0 then
								self.abovedist = mo.Diameter + ToAttachable(mo).JointOffset.X * 2;
							end
							self.leg[count] = ToAttachable(mo);
							count = count + 1;
						end
					end
				end
			end
		end
	end

	--Move the hover panels to the right spot.
	local rotadda = 0;
	local rotaddb = 0;
	if self.HFlipped == false then
		rotadda = 180;
		rotaddb = 0;
	else
		rotadda = 0;
		rotaddb = 180;
	end

	--Place the hover effects.
	self.pad1.Pos = self.Pos + Vector(lengthdir_x(6,-math.deg(self.RotAngle) + rotadda),lengthdir_y(6,-math.deg(self.RotAngle) + rotadda)) + Vector(lengthdir_x(5,-math.deg(self.RotAngle) + 90),lengthdir_y(5,-math.deg(self.RotAngle) + 90));
	self.pad1.RotAngle = self.RotAngle;
	self.pad2.Pos = self.Pos + Vector(lengthdir_x(9,-math.deg(self.RotAngle) + rotaddb),lengthdir_y(9,-math.deg(self.RotAngle) + rotaddb)) + Vector(lengthdir_x(5,-math.deg(self.RotAngle) + 90),lengthdir_y(5,-math.deg(self.RotAngle) + 90));
	self.pad2.RotAngle = self.RotAngle;

	--Keep the board alive.
	self.Health = 100;
end

function Destroy(self)
	--Don't count this as a loss.
	ActivityMan:GetActivity():ReportDeath(self.Team,-1);
	--Remove the emitters.
	self.pad1.ToDelete = true;
	self.pad2.ToDelete = true;
end