function Create(self)
	--Make this unselectable.
	self.Team = -1;

	--The acceleration value in pixels per frame.
	self.acceleration = 0.25;

	--How much to add on to acceleration when in boost mode.
	self.accelerationboost = 0.1;

	--How much to slow down when not being moved in pixels per frame.
	self.deceleration = 0.3;

	--How hard to break.  The larger, the harder to break.
	self.brakefactor = 2;

	--Maximum speed that can be accelerated to.
	self.maxspeed = 30;

	--How much to add on to the max speed when in boost mode.
	self.maxspeedboost = 15;

	--Distance to hover from ground when in normal mode.
	self.hoverheight = 35;

	--How softly the hoverboard should move to its desired position (the higher this number is, the easier it is to fall of from crashing into the ground below).
	self.landsoftness = 10;

	--Multiplied by the Y velocity to stop from hitting the ground.
	self.landdamping = 0.7;

	--The higher the number, the slower the board corrects itself, 1 being not at all and 0 being always upright.
	self.rotsoftness = 0.95;

	--Jump velocity.
	self.jumpvel = 15;

	--If the board is active.
	self.active = false;

	--The range an actor must be within to enter the vehicle.
	self.range = 50;

	--The maximum allowed drastic change in X velocity before the actor inside is knocked out of the vehicle.
	self.maxhalt = 10;

	--Stores the velocity from last frame.
	self.lastVel = Vector(0,0);

	--Minimum time between jumps, in milliseconds.
	self.jumptime = 100;

	--Minimum time between entering and exiting the vehicle.
	self.inouttime = 1000;

	--Maximum amount of boost.
	self.maxboost = 100;

	--The actor inside of the vehicle.
	self.controlactor = nil;

	--The actor's legs.
	self.leg = {};

	--Whether it should be HFlipped or not.
	self.shouldflip = false;

	--Timer to time between jumps.
	self.jumptimer = Timer();

	--Timer between exiting/entering the vehicle.
	self.inouttimer = Timer();

	--Whether the vehicle in alternate mode or not.
	self.altmode = false;

	--How much boost is left.
	self.boost = self.maxboost;

	--How quickly to regenerate boost.
	self.boostregen = 0.25;

	--How far above the board the actor should be.
	self.abovedist = 0;

	--The jetboard's two mini-rockets (glow effects).
	self.pad1 = CreateAEmitter("Jetboard Mini-Rocket");
	self.pad1:EnableEmission(false);
	MovableMan:AddParticle(self.pad1);
	self.pad2 = CreateAEmitter("Jetboard Mini-Rocket");
	self.pad2:EnableEmission(false);
	MovableMan:AddParticle(self.pad2);

	--The jetboard's back thruster.
	self.jet = CreateAEmitter("Jetboard Rocket");
	self.jet:EnableEmission(false);
	MovableMan:AddParticle(self.jet);

	--The jetboard's boost effect.
	self.boostfx = CreateAEmitter("Jetboard Turbo");
	self.boostfx:EnableEmission(false);
	MovableMan:AddParticle(self.boostfx);

	--Spawn a marker that says this vehicle's name.
	self.marker = CreateHeldDevice(string.gsub(self.PresetName," Spawned","") .. " Marker");
	MovableMan:AddItem(self.marker);
end

function Update(self)
	if self.active == true then
		if MovableMan:IsActor(self.controlactor) then
			--Set the actor's movement and position variables relative to this.
			self.controlactor.Pos = self.Pos - Vector(lengthdir_x(self.abovedist,-math.deg(self.RotAngle) + 90),lengthdir_y(self.abovedist,-math.deg(self.RotAngle) + 90));
			self.controlactor.Vel = self.Vel;
			self.controlactor.RotAngle = self.RotAngle;
			self.controlactor.AngularVel = self.AngularVel;

			--If needed, flip the board.
			if self.shouldflip == true then
				self.HFlipped = true;
				self.controlactor.HFlipped = true;
			else
				self.HFlipped = false;
				self.controlactor.HFlipped = false;
			end

			--Hover.
			local hoverpoint = 0;
			hoverpoint = SceneMan:MovePointToGround(self.Pos + Vector(self.Vel.X,0),0,3).Y - self.hoverheight;

			if self.Pos.Y > hoverpoint then
				self.Pos.Y = ((self.Pos.Y * self.landsoftness) + hoverpoint) / (self.landsoftness + 1);
				if self.Vel.Y > 0 then
					self.Vel.Y = self.Vel.Y * self.landdamping;
				end
			end

			--Get the controller.
			local controller = self:GetController();

			local ismoving = false;

			if self.Pos.Y > hoverpoint - 25 then
				--Jump
				if controller:IsState(Controller.BODY_JUMP) and self.jumptimer:IsPastSimMS(self.jumptime) then
					self.Vel.Y = -self.jumpvel;
					self.jumptimer:Reset();
				end
			else
				self.jumptimer:Reset();
			end

			--Stay upright.
			self.RotAngle = self.RotAngle * self.rotsoftness;
			self.AngularVel = self.AngularVel * self.rotsoftness;

			local pos1 = SceneMan:MovePointToGround(self.Pos - Vector(14,10),0,3);
			local pos2 = SceneMan:MovePointToGround(self.Pos + Vector(14,-10),0,3);
			local desiredangle = vector_point_direction(pos2,pos1);

			--This turns from boolean (true or false) to integer (1 or 0).  You'll see why in a bit.
			local altint = 0;
			if self.altmode == true and self.boost > 0 then
				self.boostfx:EnableEmission(true);
				altint = 1;
			else
				self.boostfx:EnableEmission(false);
			end

			--Move left.
			if controller:IsState(Controller.MOVE_LEFT) then
				if self.Vel.X <= 0 then
					--Multiply the max speed in boost mode by altint.
					--This means, if alternate mode is off, it will be 0, and if not, it will be 1 * self.maxspeedboost, which is just self.maxspeedbost.
					--This also happens for the acceleration boost.
					if self.Vel.X > -self.maxspeed - altint * self.maxspeedboost then
						self.Vel = self.Vel - Vector(lengthdir_x(self.acceleration + altint * self.accelerationboost,desiredangle),lengthdir_y(self.acceleration + altint * self.accelerationboost,desiredangle));
					end
				elseif self.Vel.X > 0 then
					self.Vel = self.Vel - Vector(lengthdir_x(self.acceleration * self.brakefactor,desiredangle),lengthdir_y(self.acceleration,desiredangle));
					if self.Vel.X < 0 then
						self.Vel.X = 0;
					end
				end
				if self.Vel.X < 0 then
					self.shouldflip = true;
				end
				ismoving = true;
			end

			--Move right.
			if controller:IsState(Controller.MOVE_RIGHT) then
				if self.Vel.X >= 0 then
					if self.Vel.X < self.maxspeed + altint * self.maxspeedboost then
						self.Vel = self.Vel + Vector(lengthdir_x(self.acceleration + altint * self.accelerationboost,desiredangle),lengthdir_y(self.acceleration + altint * self.accelerationboost,desiredangle));
					end
				elseif self.Vel.X < 0 then
					self.Vel = self.Vel + Vector(lengthdir_x(self.acceleration * self.brakefactor,desiredangle),lengthdir_y(self.acceleration,desiredangle));
					if self.Vel.X > 0 then
						self.Vel.X = 0;
					end
				end
				if self.Vel.X > 0 then
					self.shouldflip = false;
				end
				ismoving = true;
			end

			--Decelerate.
			if ismoving == false then
				self.jet:EnableEmission(false);
				if self.Vel.X < 0 then
					self.Vel.X = self.Vel.X + self.deceleration;
					if self.Vel.X > 0 then
						self.Vel.X = 0;
					end
				else
					self.Vel.X = self.Vel.X - self.deceleration;
					if self.Vel.X < 0 then
						self.Vel.X = 0;
					end
				end
			else
				self.jet:EnableEmission(true);
			end

			--Go into alternate mode.
			if controller:IsState(Controller.BODY_CROUCH) and self.Vel.X ~= 0 then
				if self.altmode == false and ismoving == true then
					--Make the boost effects appear.
					self.boostfx:TriggerBurst();
					self.altmode = true;
				end
				--Run the boost meter down.
				self.boost = self.boost - 1;
				if self.boost < 0 then
					self.boost = 0;
				end
			else
				self.altmode = false;
				--Regenerate boost if it's off.
				self.boost = self.boost + self.boostregen;
				if self.boost > self.maxboost then
					self.boost = self.maxboost;
				end
			end

			--Fire the actor's weapon.
			if controller:IsState(Controller.WEAPON_FIRE) then
				self.controlactor:GetController():SetState(Controller.WEAPON_FIRE,true);
			end

			--Reload the actor's weapon.
			if controller:IsState(Controller.AIM_SHARP) then
				self.controlactor:GetController():SetState(Controller.WEAPON_RELOAD,true);
			end

			--Aim up.
			if controller:IsState(Controller.AIM_UP) then
				self.controlactor:GetController():SetState(Controller.AIM_UP,true);
			end

			--Aim down.
			if controller:IsState(Controller.AIM_DOWN) then
				self.controlactor:GetController():SetState(Controller.AIM_DOWN,true);
			end

			--Count how many legs the actor has.
			local count = 0;
			for i = 1,#self.leg do
				if self.leg[i].RootID == self.controlactor.ID then
					count = count + 1;
				end
			end

			--If there is a sudden stop, such as hitting a wall, knock off the actor.
			local haltspeed = self.Vel.X - self.lastVel.X;
			if haltspeed > self.maxhalt or haltspeed < -self.maxhalt then
				DeactivateVehicle(self);
			end

			--Update the last speed.
			if self.active == true then
				self.lastVel = Vector(self.Vel.X,self.Vel.Y);
			end

			--Fall down if rotated too far.
			if self.RotAngle > math.pi/2 or self.RotAngle < -math.pi/2 then
				DeactivateVehicle(self);
			end

			--Disembark.
			if controller:IsState(Controller.PIE_MENU_ACTIVE) then
				self:GetController():SetState(Controller.PIE_MENU_ACTIVE,false);
				if self.inouttimer:IsPastSimMS(self.inouttime) then
					DeactivateVehicle(self);
				end
			end

			if self:IsPlayerControlled() == false then
				DeactivateVehicle(self);
			end

			if count == 0 then
				DeactivateVehicle(self);
			end
		else
			DeactivateVehicle(self);
		end
	else
		self.pad1:EnableEmission(false);
		self.pad2:EnableEmission(false);
		self.jet:EnableEmission(false);
		self.boostfx:EnableEmission(false);
		self.marker.Pos = self.Pos;
		self.boost = self.boost + self.boostregen;
		if self.boost > self.maxboost then
			self.boost = self.maxboost;
		end
		--Check for actors that are trying to enter the vehicle.
		local diff = 0;
		for actor in MovableMan.Actors do
			diff = math.sqrt((self.Pos.X - actor.Pos.X) ^ 2 + (self.Pos.Y - actor.Pos.Y) ^ 2);
			if diff <= self.range and diff >= -self.range and actor:GetController():IsState(Controller.PIE_MENU_ACTIVE) and actor:IsInGroup("Vehicles") == false and self.inouttimer:IsPastSimMS(self.inouttime) then
				self.active = true;
				self.controlactor = actor;
				ActivityMan:GetActivity():SwitchToActor(self,self.controlactor:GetController().Player,self.controlactor.Team);
				self.shouldflip = self.controlactor.HFlipped;
				self.controlactor:GetController():SetState(Controller.PIE_MENU_ACTIVE,false);
				self.controlactor:SetControllerMode(Controller.CIM_DISABLED,-1);
				self.controlactor:SetAimAngle(0);
				self.AngularVel = 0;
				self.inouttimer:Reset();
				self.GetsHitByMOs = true;
				self.RotAngle = 0;
				self.pad1:EnableEmission(true);
				self.pad1:TriggerBurst();
				self.pad2:EnableEmission(true);
				self.pad2:TriggerBurst();
				self.marker.ToDelete = true;
				self.lastVel = self.Vel;
				local mo = nil;
				local count = 1;
				for i = 1,MovableMan:GetMOIDCount() - 1 do
					mo = MovableMan:GetMOFromID(i);
					if mo.RootID == self.controlactor.ID and mo:IsGeneric() == true then
						if ToAttachable(mo).ClassName == "Leg" then
							if self.abovedist == 0 then
								self.abovedist = mo.Diameter + ToAttachable(mo).JointOffset.X * 2;
							end
							self.leg[count] = ToAttachable(mo);
							count = count + 1;
						end
					end
				end
			end
		end
	end

	--Move the hover panels to the right spot.
	local rotadda = 0;
	local rotaddb = 0;
	local padanglea = 0;
	local padangleb = 0;
	if self.HFlipped == false then
		rotadda = 180;
		rotaddb = 0;
		padanglea = math.rad(215); -- 215, 325
		padangleb = math.rad(325);
	else
		rotadda = 0;
		rotaddb = 180;
		padanglea = math.rad(325);
		padangleb = math.rad(215);
	end

	--Place the hover effects.
	self.pad1.Pos = self.Pos + Vector(lengthdir_x(10,-math.deg(self.RotAngle) + rotadda),lengthdir_y(10,-math.deg(self.RotAngle) + rotadda)) + Vector(lengthdir_x(5,-math.deg(self.RotAngle) + 90),lengthdir_y(5,-math.deg(self.RotAngle) + 90));
	self.pad1.RotAngle = self.RotAngle + padanglea;
	self.pad2.Pos = self.Pos + Vector(lengthdir_x(13,-math.deg(self.RotAngle) + rotaddb),lengthdir_y(13,-math.deg(self.RotAngle) + rotaddb)) + Vector(lengthdir_x(5,-math.deg(self.RotAngle) + 90),lengthdir_y(5,-math.deg(self.RotAngle) + 90));
	self.pad2.RotAngle = self.RotAngle + padangleb;

	--Place the thruster.
	self.jet.Pos = self.Pos + Vector(lengthdir_x(20,-math.deg(self.RotAngle) + rotadda),lengthdir_y(20,-math.deg(self.RotAngle) + rotadda)) + Vector(lengthdir_x(3,-math.deg(self.RotAngle) + 270),lengthdir_y(3,-math.deg(self.RotAngle) + 270));
	self.jet.RotAngle = self.RotAngle + math.rad(rotadda);

	--Place the boost effect.
	self.boostfx.Pos = self.Pos + Vector(lengthdir_x(20,-math.deg(self.RotAngle) + rotadda),lengthdir_y(20,-math.deg(self.RotAngle) + rotadda)) + Vector(lengthdir_x(3,-math.deg(self.RotAngle) + 270),lengthdir_y(3,-math.deg(self.RotAngle) + 270));
	self.boostfx.RotAngle = self.RotAngle + math.rad(rotadda);

	--Keep the board alive.
	self.Health = 100;
end

function Destroy(self)
	--Don't count this as a loss.
	ActivityMan:GetActivity():ReportDeath(self.Team,-1);
	--Remove the emitters.
	self.pad1.ToDelete = true;
	self.pad2.ToDelete = true;
	self.jet.ToDelete = true;
	self.boostfx.ToDelete = true;
end