function Create(self)
	--Make this unselectable.
	self.Team = -1;

	--The acceleration value in pixels per frame.
	self.acceleration = 0.2;

	--How much to slow down when not being moved in pixels per frame.
	self.deceleration = 0.3;

	--How hard to break.  The larger, the harder to break.
	self.brakefactor = 3;

	--Maximum speed that can be accelerated to.
	self.maxspeed = 20;

	--Distance to hover from ground when in normal mode.
	self.hoverheight = 35;

	--How softly the hoverboard should move to its desired position (the higher this number is, the easier it is to fall of from crashing into the ground below).
	self.landsoftness = 10;

	--Multiplied by the Y velocity to stop from hitting the ground.
	self.landdamping = 0.7;

	--The lower the number, the slower the board corrects itself, 1 being not at all and 0 being always upright.
	self.rothardness = 0.05;

	--How fast to rotate when in alternate mode.
	self.altrot = 0.1;

	--How much to slow down rotation when pushed the other way (like brakefactor, but for rotation).
	self.altrotslow = 0.5;

	--Whether the board was set into alternate mode this jump or not.
	self.altjump = false;

	--Jump velocity.
	self.jumpvel = 20;

	--If the board is active.
	self.active = false;

	--The range an actor must be within to enter the vehicle.
	self.range = 50;

	--The maximum allowed drastic change in X velocity before the actor inside is knocked out of the vehicle.
	self.maxhalt = 10;

	--Stores the velocity from last frame.
	self.lastVel = Vector(0,0);

	--Minimum time between jumps, in milliseconds.
	self.jumptime = 100;

	--Minimum time between entering and exiting the vehicle.
	self.inouttime = 1000;

	--The actor inside of the vehicle.
	self.controlactor = nil;

	--The actor's legs.
	self.leg = {};

	--Whether it should be HFlipped or not.
	self.shouldflip = false;

	--Timer to time between jumps.
	self.jumptimer = Timer();

	--Timer between exiting/entering the vehicle.
	self.inouttimer = Timer();

	--Whether the vehicle is in alternate mode or not.
	self.altmode = false;

	--How far above the board the actor should be.
	self.abovedist = 0;

	--The hoverboard's two hover panels (glow effects).
	self.pad1 = CreateAEmitter("Trickboard Hover Panel");
	MovableMan:AddParticle(self.pad1);
	self.pad2 = CreateAEmitter("Trickboard Hover Panel");
	MovableMan:AddParticle(self.pad2);

	--Spawn a marker that says this vehicle's name.
	self.marker = CreateHeldDevice(string.gsub(self.PresetName," Spawned","") .. " Marker");
	MovableMan:AddItem(self.marker);
end

function Update(self)
	if self.active == true then
		if MovableMan:IsActor(self.controlactor) then
			--Keep the angle within realistic bounds.  We only have to do this for this board as it rotates a lot and calculations mess up otherwise.
			if self.RotAngle > math.pi * 2 then
				self.RotAngle = self.RotAngle - math.pi * 2;
			elseif self.RotAngle < -math.pi * 2 then
				self.RotAngle = self.RotAngle + math.pi * 2;
			end

			--Set the actor's movement and position variables relative to this.
			self.controlactor.Pos = self.Pos - Vector(lengthdir_x(self.abovedist,-math.deg(self.RotAngle) + 90),lengthdir_y(self.abovedist,-math.deg(self.RotAngle) + 90));
			self.controlactor.Vel = self.Vel;
			self.controlactor.RotAngle = self.RotAngle;
			self.controlactor.AngularVel = self.AngularVel;

			--If needed, flip the board.
			if self.shouldflip == true then
				self.HFlipped = true;
				self.controlactor.HFlipped = true;
			else
				self.HFlipped = false;
				self.controlactor.HFlipped = false;
			end

			--Hover.
			local hoverpoint = 0;
			hoverpoint = SceneMan:MovePointToGround(self.Pos + Vector(self.Vel.X,0),0,3).Y - self.hoverheight;

			if self.Pos.Y > hoverpoint then
				self.Pos.Y = ((self.Pos.Y * self.landsoftness) + hoverpoint) / (self.landsoftness + 1);
				if self.Vel.Y > 0 then
					self.Vel.Y = self.Vel.Y * self.landdamping;
				end
				self.altjump = false;
			end

			--Get the controller.
			local controller = self:GetController();

			local ismoving = false;

			if self.Pos.Y > hoverpoint - 25 then
				--Jump
				if controller:IsState(Controller.BODY_JUMP) and self.jumptimer:IsPastSimMS(self.jumptime) then
					self.Vel.Y = -self.jumpvel;
					self.jumptimer:Reset();
				end
			else
				self.jumptimer:Reset();
			end

			--Stay upright, but in this case, only if it is at hovering level, or if it is in the air but not in alternate mode for that jump.
			if self.Pos.Y > hoverpoint - 5 or self.altjump == false then
				--Change the desired angle depending on the landing angle.
				if self.RotAngle > 0 then
					if self.RotAngle < math.pi then
						self.RotAngle = self.RotAngle - (self.RotAngle * self.rothardness);
					else
						self.RotAngle = self.RotAngle + (self.RotAngle * self.rothardness);
					end
				else
					if self.RotAngle > -math.pi then
						self.RotAngle = self.RotAngle - (self.RotAngle * self.rothardness);
					else
						self.RotAngle = self.RotAngle + (self.RotAngle * self.rothardness);
					end
				end

				self.AngularVel = self.AngularVel * self.rothardness;
			end

			local pos1 = SceneMan:MovePointToGround(self.Pos - Vector(14,10),0,3);
			local pos2 = SceneMan:MovePointToGround(self.Pos + Vector(14,-10),0,3);
			local desiredangle = vector_point_direction(pos2,pos1);

			--Move left.
			if controller:IsState(Controller.MOVE_LEFT) then
				if self.altmode == false then
					if self.Vel.X <= 0 then
						if self.Vel.X > -self.maxspeed then
							self.Vel = self.Vel - Vector(lengthdir_x(self.acceleration,desiredangle),lengthdir_y(self.acceleration,desiredangle));
						end
					elseif self.Vel.X > 0 then
						self.Vel = self.Vel - Vector(lengthdir_x(self.acceleration * self.brakefactor,desiredangle),lengthdir_y(self.acceleration,desiredangle));
						if self.Vel.X < 0 then
							self.Vel.X = 0;
						end
					end
					if self.Vel.X < 0 then
						self.shouldflip = true;
					end
				else
					--If we're in alternate mode, rotate along with the pressed buttons.
					--This is like with the braking.  We move faster if we're pussing in the opposite direction so the brakes are harder.
					if self.AngularVel >= 0 then
						self.AngularVel = self.AngularVel + self.altrot;
					else
						self.AngularVel = self.AngularVel + self.altrotslow;
						if self.AngularVel > 0 then
							self.AngularVel = 0;
						end
					end
				end
				ismoving = true;
			end

			--Move right.
			if controller:IsState(Controller.MOVE_RIGHT) then
				if self.altmode == false then
					if self.Vel.X >= 0 then
						if self.Vel.X < self.maxspeed then
							self.Vel = self.Vel + Vector(lengthdir_x(self.acceleration,desiredangle),lengthdir_y(self.acceleration,desiredangle));
						end
					elseif self.Vel.X < 0 then
						self.Vel = self.Vel + Vector(lengthdir_x(self.acceleration * self.brakefactor,desiredangle),lengthdir_y(self.acceleration,desiredangle));
						if self.Vel.X > 0 then
							self.Vel.X = 0;
						end
					end
					if self.Vel.X > 0 then
						self.shouldflip = false;
					end
				else
					if self.AngularVel <= 0 then
						self.AngularVel = self.AngularVel - self.altrot;
					else
						self.AngularVel = self.AngularVel - self.altrotslow;
						if self.AngularVel < 0 then
							self.AngularVel = 0;
						end
					end						
				end
				ismoving = true;
			end

			--Decelerate.
			if ismoving == false then
				if self.Vel.X < 0 then
					self.Vel.X = self.Vel.X + self.deceleration;
					if self.Vel.X > 0 then
						self.Vel.X = 0;
					end
				else
					self.Vel.X = self.Vel.X - self.deceleration;
					if self.Vel.X < 0 then
						self.Vel.X = 0;
					end
				end
			end

			--Go into alternate mode.
			if controller:IsState(Controller.BODY_CROUCH) then
				self.altmode = true;
				self.altjump = true;
			else
				self.altmode = false;
			end

			--Fire the actor's weapon.
			if controller:IsState(Controller.WEAPON_FIRE) then
				self.controlactor:GetController():SetState(Controller.WEAPON_FIRE,true);
			end

			--Reload the actor's weapon.
			if controller:IsState(Controller.AIM_SHARP) then
				self.controlactor:GetController():SetState(Controller.WEAPON_RELOAD,true);
			end

			--Aim up.
			if controller:IsState(Controller.AIM_UP) then
				self.controlactor:GetController():SetState(Controller.AIM_UP,true);
			end

			--Aim down.
			if controller:IsState(Controller.AIM_DOWN) then
				self.controlactor:GetController():SetState(Controller.AIM_DOWN,true);
			end

			--Count how many legs the actor has.
			local count = 0;
			for i = 1,#self.leg do
				if self.leg[i].RootID == self.controlactor.ID then
					count = count + 1;
				end
			end

			--If there is a sudden stop, such as hitting a wall, knock off the actor.
			local haltspeed = self.Vel.X - self.lastVel.X;
			if haltspeed > self.maxhalt or haltspeed < -self.maxhalt then
				DeactivateVehicle(self);
			end

			--Update the last speed.
			if self.active == true then
				self.lastVel = Vector(self.Vel.X,self.Vel.Y);
			end

			--Disembark.
			if controller:IsState(Controller.PIE_MENU_ACTIVE) then
				self:GetController():SetState(Controller.PIE_MENU_ACTIVE,false);
				if self.inouttimer:IsPastSimMS(self.inouttime) then
					DeactivateVehicle(self);
				end
			end

			--Fall down if rotated too far, but only if it's at hovering level (this allows for rotating in the air.)
			--We'll set this to false if we haven't rotated too far.
			local toofar = true;
			if self.RotAngle >= 0 then
				--Recall that we're doing this in radians.  In radians, pi = 180 degrees.  So...
				if self.RotAngle < math.pi / 2 then
				--If the angle is less than 90 degrees, then it's fine.
					toofar = false;
				elseif self.RotAngle > math.pi * 1.5 then
				--Pi * 1.5 in radians is the same as 180 * 1.5, which is 270.  So if the angle is greater than 270 degrees, that's fine too.
					toofar = false;
				end
				--In total this gives a 180 degree leeway.
			else
				--Now we do the same for negative angles, which happen when you rotate left.  The calculations are nearly exactly the same.
				if self.RotAngle > -math.pi / 2 then
					toofar = false;
				elseif self.RotAngle < -math.pi * 1.5 then
					toofar = false;
				end
			end

			--If we've not encountered any proof of the board being upright and it is at hovering level, make the driver fall off.
			if toofar == true and self.Pos.Y > hoverpoint - 5 then
				DeactivateVehicle(self);
			end

			if self:IsPlayerControlled() == false then
				DeactivateVehicle(self);
			end

			if count == 0 then
				DeactivateVehicle(self);
			end
		else
			DeactivateVehicle(self);
		end
	else
		self.pad1:EnableEmission(false);
		self.pad2:EnableEmission(false);
		self.marker.Pos = self.Pos;
		--Check for actors that are trying to enter the vehicle.
		local diff = 0;
		for actor in MovableMan.Actors do
			diff = math.sqrt((self.Pos.X - actor.Pos.X) ^ 2 + (self.Pos.Y - actor.Pos.Y) ^ 2);
			if diff <= self.range and diff >= -self.range and actor:GetController():IsState(Controller.PIE_MENU_ACTIVE) and actor:IsInGroup("Vehicles") == false and self.inouttimer:IsPastSimMS(self.inouttime) then
				self.active = true;
				self.controlactor = actor;
				ActivityMan:GetActivity():SwitchToActor(self,self.controlactor:GetController().Player,self.controlactor.Team);
				self.shouldflip = self.controlactor.HFlipped;
				self.controlactor:GetController():SetState(Controller.PIE_MENU_ACTIVE,false);
				self.controlactor:SetControllerMode(Controller.CIM_DISABLED,-1);
				self.controlactor:SetAimAngle(0);
				self.AngularVel = 0;
				self.inouttimer:Reset();
				self.GetsHitByMOs = true;
				self.RotAngle = 0;
				self.pad1:EnableEmission(true);
				self.pad1:TriggerBurst();
				self.pad2:EnableEmission(true);
				self.pad2:TriggerBurst();
				self.marker.ToDelete = true;
				self.lastVel = self.Vel;
				--Store the actor's legs as pointers so that if he has none, he falls off the board.
				local mo = nil;
				local count = 1;
				for i = 1,MovableMan:GetMOIDCount() - 1 do
					mo = MovableMan:GetMOFromID(i);
					if mo.RootID == self.controlactor.ID and mo:IsGeneric() == true then
						if ToAttachable(mo).ClassName == "Leg" then
							if self.abovedist == 0 then
								self.abovedist = mo.Diameter + ToAttachable(mo).JointOffset.X * 2;
							end
							self.leg[count] = ToAttachable(mo);
							count = count + 1;
						end
					end
				end
			end
		end
	end

	--Move the hover panels to the right spot.
	local rotadda = 0;
	local rotaddb = 0;
	if self.HFlipped == false then
		rotadda = 180;
		rotaddb = 0;
	else
		rotadda = 0;
		rotaddb = 180;
	end

	--Place the hover effects.
	self.pad1.Pos = self.Pos + Vector(lengthdir_x(11,-math.deg(self.RotAngle) + rotadda),lengthdir_y(11,-math.deg(self.RotAngle) + rotadda)) + Vector(lengthdir_x(7,-math.deg(self.RotAngle) + 90),lengthdir_y(7,-math.deg(self.RotAngle) + 90));
	self.pad1.RotAngle = self.RotAngle;
	self.pad2.Pos = self.Pos + Vector(lengthdir_x(11,-math.deg(self.RotAngle) + rotaddb),lengthdir_y(11,-math.deg(self.RotAngle) + rotaddb)) + Vector(lengthdir_x(7,-math.deg(self.RotAngle) + 90),lengthdir_y(7,-math.deg(self.RotAngle) + 90));
	self.pad2.RotAngle = self.RotAngle;

	--Keep the board alive.
	self.Health = 100;
end

function Destroy(self)
	--Don't count this as a loss.
	ActivityMan:GetActivity():ReportDeath(self.Team,-1);
	--Remove the emitters.
	self.pad1.ToDelete = true;
	self.pad2.ToDelete = true;
end